@@ -27,7 +27,7 @@ class OwncloudControl:
         return self.access.http()
 
     def url(self):
-        urls = self.insider.service_urls(self.config.service_name)
+        urls = self.insider.service_info(self.config.service_name)
         return urls.full_url
 
 
